package edu.calpoly.Samplejwong18;

import android.app.Activity;
import android.content.Context;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.os.Bundle;
import android.widget.LinearLayout;
import android.widget.TextView;

/**
 * Displays and constantly updates the Accelerometer sensor values: lateral, longitudinal, and vertical.
 * 
 * @author Jessica Wong (jwong18)
 *
 */
public class AccelMain extends Activity {
    /**
     * TextViews used to display accelerometer sensor values
     */
	protected TextView lateralTV;
	protected TextView longitudinalTV;
	protected TextView verticalTV;
	
	/**
	 * Sensor
	 */
	protected Sensor sensor;
	protected SensorManager sensorManager;
	
	protected LinearLayout root;
	
	/** Called when the activity is first created. */
    @Override 
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        
        //initialize accelerometer Sensor and SensorManager
        sensorManager = (SensorManager)getSystemService(Context.SENSOR_SERVICE);
        sensor = sensorManager.getDefaultSensor(Sensor.TYPE_ACCELEROMETER);
        
        //register SensorEventListener to get updates on the accelerometer values
        sensorManager.registerListener(mySensorEventListener, sensor, SensorManager.SENSOR_DELAY_NORMAL);
        
        initLayout();
    }
    
    /**
     * Initializes layout
     */
    private void initLayout() {
    	//initialize layout
		root = new LinearLayout(this);
		root.setOrientation(LinearLayout.VERTICAL);
		
		//initialize TextViews
    	lateralTV = new TextView(this);		
    	longitudinalTV = new TextView(this);
    	verticalTV = new TextView(this);
    	
    	//setting TextViews text size
    	lateralTV.setTextSize(20);	
    	longitudinalTV.setTextSize(20);
    	verticalTV.setTextSize(20);
    	
    	//adding TextViews to layout
    	root.addView(lateralTV);
    	root.addView(longitudinalTV);
    	root.addView(verticalTV);
    	
    	//setting content view to root layout
    	setContentView(root);
    }
    
    /**
     * SensorEventListener that listens on the accelerometer 
     */
    private final SensorEventListener mySensorEventListener = new SensorEventListener() {
    	public void onSensorChanged(SensorEvent sensorEvent) {
    		if(sensorEvent.sensor.getType() == Sensor.TYPE_ACCELEROMETER) {
    			/* when the listener senses a change it will call the
    			 * updateValues() and pass in the new sensor values
    			 * value[0] is the lateral value
    			 * value[1] is the longitudinal value
    			 * value[2] is the verticals value
    			 */
    			updateValues(sensorEvent.values[0], sensorEvent.values[1], sensorEvent.values[2]);
    		}
    	}
    	
    	/**
    	 * Not needed in this application, but can be used to react to a changed Sensor accuracy
    	 */
		public void onAccuracyChanged(Sensor arg0, int arg1) {}
    };
    
    @Override
    protected void onResume() {
    	super.onResume();
    	//registers the istener on resume
    	sensorManager.registerListener(mySensorEventListener, sensor, SensorManager.SENSOR_DELAY_NORMAL);
    }
    
    @Override
    protected void onPause() {
    	//unregister the listener
    	sensorManager.unregisterListener(mySensorEventListener);
    	super.onPause();
    }
    
    @Override
    protected void onStop() {
    	//unregister the listener
        sensorManager.unregisterListener(mySensorEventListener);
        super.onStop();
    }   
    
    /**
     * Updates the TextView text with the passed in accelerometer values
     *  
     * @param lateral lateral value of accelerometer
     * @param longitudinal longitudinal value of accelerometer
     * @param vertical vertical value of accelerometer
     */
    private void updateValues(float lateral, float longitudinal, float vertical) {
    	lateralTV.setText(		"Lateral:            " + lateral + " m/s^2");
    	longitudinalTV.setText(	"Longitudinal:  " + longitudinal + " m/s^2");
    	verticalTV.setText(		"Vertical:           " + vertical + " m/s^2");
    	
    }
}